@@ -24,6 +24,8 @@ RPC::Xmlrpc_c::Client::Curl - Curl XML transport for RPC::Xmlrpc_c::Client
                                      CLIENT    => \my $client,
                                      ERROR     => \my $error2);
 
+=cut
+
 =head1 DESCRIPTION
 
 This module provides client XML transport functions for use with a
@@ -41,7 +43,7 @@ require Exporter;
 require DynaLoader;
 our @ISA = qw(Exporter DynaLoader);
 our @EXPORT = qw( createObject call );
-our $VERSION = "1.02";
+our $VERSION = "1.05";
 use Carp;
 use Data::Dumper;
 
@@ -57,51 +59,70 @@ if ($error) {
 
 =head2 RPC::Xmlrpc_c::Client::Curl->createObject
 
- RPC::Xmlrpc_c::Client::Curl->createObject(TRANSPORT      => \my $transport,
-                                           TRANSPORTPARMS => {},
-                                           ERROR          => \my $error1);
+ RPC::Xmlrpc_c::Client::Curl->createObject(
+    TRANSPORT      => \my $transport,
+    TRANSPORTPARMS => {},
+    ERROR          => \my $error1);
 
 This creates a C<RPC::Xmlrpc_c::Client::Curl> object.
 
 Arguments:
 
- C<TRANSPORT>
+=over 2
 
-  This is a reference to a scalar variable that the method sets to
-  the handle of the new object.
+C<TRANSPORT>
 
-  If you do not specify this option, you don't get a handle for the
-  object, and as no reference is created to the object, it gets destroyed
-  as soon as it is created.  This is not very useful.
+=over 2
 
-  If the method fails to create the object, it sets the variable
-  arbitrarily.  See C<ERROR>.
+This is a reference to a scalar variable that the method sets to
+the handle of the new object.
 
- C<TRANSPORTPARMS>
+If you do not specify this option, you don't get a handle for the
+object, and as no reference is created to the object, it gets destroyed
+as soon as it is created.  This is not very useful.
 
-  This is a reference to a hash of named transport parameters.
+If the method fails to create the object, it sets the variable
+arbitrarily.  See C<ERROR>.
 
-  Example:
+=back
 
-     { network_interface  => 'eth0',
-       no_ssl_verify_peer => 1
-     }
+C<TRANSPORTPARMS>
 
-  The names (hash keys) are the names of the members of
-  C<struct xmlrpc_curl_xportparms> in Xmlrpc-c.
+=over 2
 
-  Any transport parameter you don't specify defaults to the Xmlrpc-c
-  default.  If you specify a key that is not a valid transport
-  parameter name, createObject() ignores it.
+This is a reference to a hash of named transport parameters.
 
- C<ERROR>
+Example:
 
-  This is a reference to a scalar variable that the method sets to
-  a text description of why it is unable to create the object.  If
-  it I<is> able to create the object, it sets it to C<undef>.
+   { network_interface  => 'eth0',
+     no_ssl_verify_peer => 1,
+     timeout => 5
+   }
 
-  If you do not specify this option and creation fails, the method
-  croaks.
+The names (hash keys) are the names of the members of
+C<struct xmlrpc_curl_xportparms> in Xmlrpc-c.  This subroutine recognizes
+only the parameters up through C<timeout>.
+
+Any transport parameter you don't specify defaults to the Xmlrpc-c
+default.  If you specify a key that is not a valid transport
+parameter name, createObject() ignores it.
+
+=back
+
+C<ERROR>
+
+=over 2
+
+This is a reference to a scalar variable that the method sets to
+a text description of why it is unable to create the object.  If
+it I<is> able to create the object, it sets it to C<undef>.
+
+If you do not specify this option and creation fails, the method
+croaks.
+
+=back
+
+=back
  
 =cut
 
